# poweringclasses
#
# Find classes (and element orders) which power up to a given
# class.
#
# CT:    character table
# class: ATLAS name of class
#
# e.g. The class 2B in M12 can be found by powering up any element
# of order 4 or 8 or any element in class 6B.
# gap> CT := CharacterTable("M12");
# CharacterTable( "M12" )
# gap> poweringclasses(CT, "2B");
# rec( classes := [ "2B", "4A", "4B", "6B", "8A", "8B" ], 
#   alloforder := [ 4, 8 ] )

poweringclasses := function(CT, class)
    
    local i, o, names, orders, classes, classnum, powers,
          classesoforder, alloforder;
    
    names := ClassNames(CT, "ATLAS");
    classnum := Position(names, class);
    orders := OrdersClassRepresentatives(CT);
    classes := [];
    alloforder := [];
    
    for i in [1..Size(names)] do
        if orders[i] mod orders[classnum] = 0 then
            powers := PowerMap(CT, orders[i]/orders[classnum]);
            if powers[i] = classnum then
                Add(classes, names[i]);
            fi;
        fi;
    od;
    
    for o in Set(orders) do
        classesoforder := List(Filtered([1..Size(names)],
                                  x->orders[x] = o), y->names[y]);
        if IsSubset(classes, classesoforder) then
            Add(alloforder, o);
        fi;
            
    od;
    
    return rec(classes := classes,
               alloforder := alloforder);
end;
